@@ -78,9 +78,9 @@ ConfigureDialog::ConfigureDialog( TDEConfig *_config, HardwareInfo *_hwinfo, Set
 	scheme_changed = false;
 	displayed_WARN_autosuspend = false;
 
-	// check if brightness is supporte
+	// check if brightness is supported
 	if(hwinfo->supportBrightness()) {
-		brightnessLevels = hwinfo->getMaxBrightnessLevel() -1;
+		brightnessLevels = hwinfo->getMaxBrightnessLevel();
 		brightness_last = hwinfo->getCurrentBrightnessLevel();
 	} else {
 		brightnessLevels = -1;
@@ -119,7 +119,7 @@ ConfigureDialog::ConfigureDialog( TDEConfig *_config, HardwareInfo *_hwinfo, Set
 	tL_valueBrightness->setFrameStyle(TQFrame::Panel | TQFrame::Sunken);
 	tL_valueBrightness->setBackgroundMode(TQt::PaletteBase);
 	tL_valueBrightness->setAlignment(TQt::AlignCenter);
-	tL_valueBrightness->setFocusPolicy(TQ_NoFocus);
+	tL_valueBrightness->setFocusPolicy(TQWidget::NoFocus);
 
 	// hide Lid item if this is not a laptop
 	if (!hwinfo->isLaptop())
@@ -569,7 +569,7 @@ void ConfigureDialog::setConfigToDialog( int schemeID ){
 	else {
 		cB_Brightness->setEnabled(false);
 		gB_Brightness->setEnabled(false);
-		tL_brightness->setText(i18n("Your Hardware currently not support changing the brightness "
+		tL_brightness->setText(i18n("Your hardware does not currently support changing the brightness "
 					    "of your display."));
 	}
 
@@ -1652,7 +1652,7 @@ void ConfigureDialog::brightnessSlider_sliderMoved( int new_value ) {
 	if (cB_Brightness->isEnabled() && cB_Brightness->isChecked()) {
 		scheme_valueChanged();
 		tL_valueBrightness->setText(TQString::number(new_value) + " %");
-		hwinfo->setBrightness(-1, new_value);
+		hwinfo->setBrightnessPercentage(new_value);
 		pB_resetBrightness->setEnabled(true);
 		brightness_changed = true;
 	}
@@ -1664,7 +1664,7 @@ void ConfigureDialog::brightnessSlider_sliderMoved( int new_value ) {
 void ConfigureDialog::pB_resetBrightness_clicked( ) {
 	kdDebugFuncIn(trace);
 
-	hwinfo->setBrightness(brightness_last, -1);
+	hwinfo->setBrightnessLevel(brightness_last);
 	brightnessSlider->setValue(brightness_last);
 	pB_resetBrightness->setEnabled(false);
 	brightness_changed = false;
