@@ -30,6 +30,7 @@
 
 // include global header
 #include <fcntl.h>
+#include <math.h>
 
 // include QT header
 #include <tqtimer.h>
@@ -207,11 +208,6 @@ void HardwareInfo::processKeyPressEvent(unsigned int keycode, TDEEventDevice* ed
 		} else if (((edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
 			&& (keycode == KEY_SUSPEND)) {
 			TQTimer::singleShot(50, this, TQT_SLOT(emitS2diskButtonPressed()));
-// 		} else if (value.startsWith("brightness-")) {
-// 			if (!brightness_in_hardware && value.endsWith("-up"))
-// 				TQTimer::singleShot(50, this, TQT_SLOT(brightnessUpPressed()));
-// 			else if (!brightness_in_hardware && value.endsWith("-down"))
-// 				TQTimer::singleShot(50, this, TQT_SLOT(brightnessDownPressed()));
 		}
 
 	kdDebugFuncOut(trace);
@@ -898,30 +894,18 @@ bool HardwareInfo::suspend( suspend_type suspend ) {
 }
 
 /*!
- * Function to set brightness via TDE hardware library (if supported by hardware)
+ * Function to set brightness level via TDE hardware library (if supported by hardware)
  * \param level		Integer with the level to set, (range: 0 - \ref availableBrightnessLevels )
- * \param percent	Integer with the brightness percentage to set
  * \return boolean with result of the operation
  * \retval true  	if successful
  * \retval false 	else, if a error occurs
  */
-bool HardwareInfo::setBrightness ( int level, int percent ){
-	if (trace) kdDebug() << funcinfo << "IN: " << "level: " << level << " percent: " << percent << endl;
+bool HardwareInfo::setBrightnessLevel(int level)
+{
+	if (trace) kdDebug() << funcinfo << "IN: " << "level: " << level << endl;
 
 	bool retval = false;
-
-	if ((level == -1) && (percent >= 0)) {
-		if (percent == 0) {
-			level = 0;
-		} else if (percent >= 98) {
-			level = (availableBrightnessLevels - 1);
-		} else {
-			level = (int)((float)availableBrightnessLevels * ((float)percent/100.0));
-			if (level > (availableBrightnessLevels -1))
-				level = availableBrightnessLevels -1;
-			kdDebug() << "percentage mapped to new level: " << level << endl;
-		}
-	}
+	int maxBrightness = getMaxBrightnessLevel();
 
 	// Use the first backlight in the list
 	TDEGenericHardwareList hwlist = m_hwdevices->listByDeviceClass(TDEGenericDeviceType::Backlight);
@@ -934,8 +918,16 @@ bool HardwareInfo::setBrightness ( int level, int percent ){
 			checkBrightness();
 		}
 
-		if (!brightness || (level < 0 ) || (level >= availableBrightnessLevels)) {
-			kdError() << "Change brightness or requested level not supported " << endl;
+		// Make sure level is within valid range
+		if (level < 0) {
+			level = 0;
+		}
+		else if (level > maxBrightness) {
+			level = maxBrightness;
+		}
+
+		if (!brightness) {
+			kdError() << "Change brightness not supported " << endl;
 		} else {
 			if (currentBrightnessLevel == level) {
 				kdDebug() << "Brightness level not changed, requested level == current level" << endl;
@@ -953,6 +945,60 @@ bool HardwareInfo::setBrightness ( int level, int percent ){
 	return retval;
 }
 
+/*!
+ * Function to set brightness percentage via TDE hardware library (if supported by hardware)
+ * \param percent	Integer with the brightness percentage to set
+ * \return boolean with result of the operation
+ * \retval true  	if successful
+ * \retval false 	else, if a error occurs
+ */
+bool HardwareInfo::setBrightnessPercentage(int percent)
+{
+	if (trace) kdDebug() << funcinfo << "IN: " << " percent: " << percent << endl;
+
+	bool retval = false;
+
+	// Use the first backlight in the list
+	TDEGenericHardwareList hwlist = m_hwdevices->listByDeviceClass(TDEGenericDeviceType::Backlight);
+	TDEGenericDevice *hwdevice;
+	hwdevice = hwlist.first();
+	TDEBacklightDevice *backlightdevice = static_cast<TDEBacklightDevice*>(hwdevice);
+
+	if (backlightdevice) {
+		if (!brightness) {
+			checkBrightness();
+		}
+
+		if (!brightness) {
+			kdError() << "Change brightness not supported " << endl;
+		}
+		else {
+			// Make sure percentage is within valid range
+			if (percent < 0) {
+				percent = 0;
+			}
+			else if (percent > 100) {
+				percent = 100;
+			}
+
+			int level = (int)round(getMaxBrightnessLevel() * percent / 100.0);
+			if (currentBrightnessLevel == level) {
+				kdDebug() << "Brightness level not changed, requested level == current level" << endl;
+				retval = true;
+			}
+			else {
+				backlightdevice->setRawBrightness(level);
+				retval = true;
+			}
+		}
+	}
+
+	// check for actual brightness level to be sure everything was set correct
+	checkCurrentBrightness();
+	kdDebugFuncOut(trace);
+	return retval;
+}
+
 /*!
  * Function to set the CPU frequency policy via TDE hardware library.
  * \param cpufreq 	enum of cpufreq_type with the policy to set
@@ -1137,35 +1183,10 @@ bool HardwareInfo::setBrightnessUp(int percentageStep) {
 
 	checkCurrentBrightness();
 
-	if (supportBrightness() && (getCurrentBrightnessLevel() >= 0) &&
-            (getCurrentBrightnessLevel() != (getMaxBrightnessLevel()-1))) {
-		int setTo = 0;
-		int minPercStep = 10;
-		int currentPerc = (int)(((float)getCurrentBrightnessLevel()/(float)(getMaxBrightnessLevel()-1))*100.0);
-
-		if (percentageStep > 0 && (percentageStep <= (100-currentPerc))) {
-			minPercStep = percentageStep;
-		}
-
-		if ((currentPerc + minPercStep) > 100) {
-			// set to 100 %
-			setTo = getMaxBrightnessLevel() -1;
-		} else {
-			setTo = (int)(((float)(getMaxBrightnessLevel()-1))*(((float)(currentPerc + minPercStep))/100.0));
-			if ((setTo == getCurrentBrightnessLevel()) && (setTo <  (getMaxBrightnessLevel() -1))) {
-				setTo++;
-			}
-		}
-
-		if (trace) {
-			kdDebug() << "Max: " << getMaxBrightnessLevel()
-				  << " Current: " << getCurrentBrightnessLevel()
-				  << " minPercStep: " << minPercStep
-				  << " currentPerc: " << currentPerc
-				  << " setTo: " << setTo << endl;
-		}
-
-		retval = setBrightness(setTo, -1);
+	if (supportBrightness() && percentageStep > 0)
+	{
+		int currentPerc = (int)round(100.0 * getCurrentBrightnessLevel() / getMaxBrightnessLevel());
+		retval = setBrightnessPercentage(currentPerc + percentageStep);
 	}
 
 	kdDebugFuncOut(trace);
@@ -1186,78 +1207,15 @@ bool HardwareInfo::setBrightnessDown(int percentageStep) {
 
 	checkCurrentBrightness();
 
-	if (supportBrightness() && (getCurrentBrightnessLevel() > 0)) {
-		int setTo = 0;
-		int minPercStep = 10;
-		int currentPerc = (int)(((float)getCurrentBrightnessLevel()/(float)(getMaxBrightnessLevel()-1))*100.0);
-
-		if (percentageStep > 0 && (percentageStep < currentPerc)) {
-			minPercStep = percentageStep;
-		}
-
-		if ((currentPerc - minPercStep) < 0) {
-			setTo = 0;
-		} else {
-			setTo = (int)(((float)(getMaxBrightnessLevel()-1))*(((float)(currentPerc - minPercStep))/100.0));
-			if ((setTo == getCurrentBrightnessLevel()) && (setTo > 0)) {
-				setTo--;
-			}
-		}
-
-		if (trace) {
-			kdDebug() << "Max: " << getMaxBrightnessLevel()
-				  << " Current: " << getCurrentBrightnessLevel()
-				  << " minPercStep: " << minPercStep
-				  << " currentPerc: " << currentPerc
-				  << " setTo: " << setTo << endl;
-		}
-
-		retval = setBrightness(setTo, -1);
+	if (supportBrightness() && percentageStep > 0) {
+		int currentPerc = (int)round(100.0 * getCurrentBrightnessLevel() / getMaxBrightnessLevel());
+		retval = setBrightnessPercentage(currentPerc - percentageStep);
 	}
 
 	kdDebugFuncOut(trace);
 	return retval;
 }
 
-/*!
- * Function to handle the signal for the brightness up button/key
- */
-void HardwareInfo::brightnessUpPressed() {
-	kdDebugFuncIn(trace);
-
-	if (brightness) {
-		if (!sessionIsActive) {
-			kdWarning() << "Session is not active, don't react on brightness up key event!" << endl;
-		} else {
-			if (currentBrightnessLevel < availableBrightnessLevels) {
-				setBrightnessUp();
-			} else {
-				kdWarning() << "Could not set brightness to higher level, it's already set to max." << endl;
-			}
-		}
-	}
-	kdDebugFuncOut(trace);
-}
-
-/*!
- * Function to handle the signal for the brightness down button/key
- */
-void HardwareInfo::brightnessDownPressed() {
-	kdDebugFuncIn(trace);
-
-	if (brightness) {
-		if (!sessionIsActive) {
-			kdWarning() << "Session is not active, don't react on brightness down key event!" << endl;
-		} else {
-			if (currentBrightnessLevel > 0) {
-				setBrightnessDown();
-			} else {
-				kdWarning() << "Could not set brightness to lower level, it's already set to min." << endl;
-			}
-		}
-	}
-}
-
 // --> private helper slots to forward/handle events -- END <--
 
 // --> get private members section -- START <---
@@ -1288,7 +1246,7 @@ bool HardwareInfo::getLidclose() const {
  */
 int HardwareInfo::getMaxBrightnessLevel() const {
 	if (brightness)
-		return availableBrightnessLevels;
+		return availableBrightnessLevels - 1;
 	else
 		return -1;
 }
