@@ -32,11 +32,6 @@
 #ifndef _BATTERY_H_
 #define _BATTERY_H_
 
-// Global Header
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // QT - Header
 #include <tqstring.h>
 #include <tqstringlist.h>
@@ -49,7 +44,7 @@
 
 class Battery : public TQObject {
 
-	Q_OBJECT
+	TQ_OBJECT
   
 
 private:
@@ -282,16 +277,6 @@ public:
 	//! reports the chargelevel in percent when battery goes to state critical
 	int getCritLevel() const;
 
-	//writeable access to internals
-	//! Resets the current TDE hardware library udi used by the one given
-	/*!
-	* The given TQString will be (checked and) used as new TDE hardware library udi for the battery.
-	* But don't forget to do a recheck of the battery afterwards.
-	* \li returns TRUE: if reset was successfull
-	* \li returns FALSE: if reset couldn't be applied
-	*/
-	bool resetUdi(TQString);
-
 	//! sets the chargelevel in percent when battery should go into state warning
 	void setWarnLevel(int _warn_level);
 	//! sets the chargelevel in percent when battery should go into state low
@@ -336,8 +321,7 @@ enum BAT_STATE {
 	BAT_WARN,
 	BAT_LOW,
 	BAT_CRIT,
-	BAT_NORM,
-	BAT_HAL_ERROR
+	BAT_NORM
 };
 
 #endif
