@@ -58,7 +58,7 @@ extern "C" {
 
 class inactivity : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 public:
