@@ -48,7 +48,7 @@
 */
 class screen : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 private:
