@@ -23,6 +23,8 @@
 #include <config.h>
 #endif
 
+#include <math.h>
+
 // KDE headers:
 #include <tdeaboutapplication.h>
 #include <tdeapplication.h>
@@ -148,7 +150,8 @@ tdepowersave::tdepowersave( bool force_acpi_check, bool trace_func ) : KSystemTr
 	BAT_WARN_ICON_Timer = new TQTimer(this);
 	connect(BAT_WARN_ICON_Timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(do_setIconBG()));
 
-	AUTODIMM_Timer = new TQTimer(this);
+	m_autoDimmTimer = new TQTimer(this);
+	connect(m_autoDimmTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(do_dimm()));
 
 	initMenu();
 	update();
@@ -167,6 +170,7 @@ tdepowersave::~tdepowersave(){
 	delete display;
 	delete settings;
 	delete autoSuspend;
+	delete m_autoDimmTimer;
 #ifdef ENABLE_YAST_ENTRY
 	delete yast2;
 #endif
@@ -1072,25 +1076,22 @@ void tdepowersave::do_downDimm() {
 	kdDebugFuncIn(trace);
 
 	if (hwinfo->supportBrightness()) {
-		if (!AUTODIMM_Timer->isActive()) {
-			int dimmToLevel = (int)((float)hwinfo->getMaxBrightnessLevel()*((float)settings->autoDimmTo/100.0));
+		if (!m_autoDimmTimer->isActive()) {
+			int dimmToLevel = (int)round(hwinfo->getMaxBrightnessLevel() * settings->autoDimmTo / 100.0);
 
 			// check if we really need to dimm down
 			if (dimmToLevel < hwinfo->getCurrentBrightnessLevel()) {
-				int steps = hwinfo->getCurrentBrightnessLevel() - dimmToLevel;
-				int timePerStep = (1500 / steps);
-
+				m_dimmRequestedLevel = dimmToLevel;
+				m_dimmStep = (hwinfo->getCurrentBrightnessLevel() - dimmToLevel) / 10 + 1;
+				m_dimmTimeoutCounter = 0;
 				autoDimmDown = true;
-
-				AUTODIMM_Timer = new TQTimer(this);
-				connect(AUTODIMM_Timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(do_dimm()));
-				AUTODIMM_Timer->start(timePerStep, false);
+				m_autoDimmTimer->start(100, false);
 			} else {
 				kdWarning() << "Don't dimm down, current level is already lower than requested Level" << endl;
 			}
 		} else {
 			// wait until the timer is stopped, try later!
-			TQTimer::singleShot(1500, this, TQT_SLOT(do_downDimm()));
+			TQTimer::singleShot(2000, this, TQT_SLOT(do_downDimm()));
 		}
 	}
 
@@ -1111,28 +1112,24 @@ void tdepowersave::do_upDimm() {
 	//NOTE we go back to the value of the scheme and not the last on, to reduce trouble with the scheme
 
 	if (hwinfo->supportBrightness()) {
-		if (!AUTODIMM_Timer->isActive()) {
-			int dimmToLevel = (int)((float)hwinfo->getMaxBrightnessLevel()*((float)settings->brightnessValue/100.0));
+		if (!m_autoDimmTimer->isActive()) {
+			int dimmToLevel = (int)round(hwinfo->getMaxBrightnessLevel() * settings->brightnessValue / 100.0);
 
 			// check if we really need to dimm up
 			if (dimmToLevel > hwinfo->getCurrentBrightnessLevel()) {
-				int steps = dimmToLevel - hwinfo->getCurrentBrightnessLevel();
-				int timePerStep = (750 / steps);
-
+				m_dimmRequestedLevel = dimmToLevel;
+				m_dimmStep = (dimmToLevel - hwinfo->getCurrentBrightnessLevel()) / 10 + 1;
+				m_dimmTimeoutCounter = 0;
 				autoDimmDown = false;
-
-				AUTODIMM_Timer = new TQTimer(this);
-				connect(AUTODIMM_Timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(do_dimm()));
-				AUTODIMM_Timer->start(timePerStep, false);
-
-				// start autodimm again
-				setAutoDimm(false);
+				m_autoDimmTimer->start(100, false);
 			} else {
 				kdWarning() << "Don't dimm up, current level is already above requested Level" << endl;
 			}
+			// start autodimm again
+			setAutoDimm(false);
 		} else {
 			// wait until the timer is stopped, try later!
-			TQTimer::singleShot(750, this, TQT_SLOT(do_downDimm()));
+			TQTimer::singleShot(2000, this, TQT_SLOT(do_downDimm()));
 		}
 	}
 
@@ -1149,15 +1146,22 @@ void tdepowersave::do_upDimm() {
 void tdepowersave::do_dimm() {
 	kdDebugFuncIn(trace);
 
+	if (m_dimmStep <= 0 || m_dimmTimeoutCounter > 30)
+	{
+		m_autoDimmTimer->stop();
+		return;
+	}
+
+	++m_dimmTimeoutCounter;
 	int current = hwinfo->getCurrentBrightnessLevel();
 
 	if (autoDimmDown) {
 		// dimm the display down
-		if (current > 0 &&
-		    current > ((int)((float)hwinfo->getMaxBrightnessLevel()*((float)settings->autoDimmTo/100.0))-1)) {
-			hwinfo->setBrightness((current -1) , -1);
+		if (current > 0 && current > (m_dimmRequestedLevel * 1.005)) {
+			hwinfo->setBrightnessLevel(current - m_dimmStep);
 		} else {
-			AUTODIMM_Timer->stop();
+			m_autoDimmTimer->stop();
+			m_dimmStep = 0;
 
 			// start checking if the user get active again
 			// NOTE: we start this here because the X-Server detect brightness changes as
@@ -1166,10 +1170,11 @@ void tdepowersave::do_dimm() {
 		}
 	} else {
 		// dimm the display up
-		if (current < ((int)((float)hwinfo->getMaxBrightnessLevel()*((float)settings->brightnessValue/100.0))-1)) {
-			hwinfo->setBrightness((current +1) , -1);
+		if (current < (m_dimmRequestedLevel * 0.995)) {
+			hwinfo->setBrightnessLevel(current + m_dimmStep);
 		} else {
-			AUTODIMM_Timer->stop();
+			m_autoDimmTimer->stop();
+			m_dimmStep = 0;
 		}
 	}
 
@@ -1925,7 +1930,7 @@ void tdepowersave::setSchemeSettings(){
 	// --> set brightness settings
 	if(settings->brightness && hwinfo->supportBrightness()) {
 		// set to given values
-		hwinfo->setBrightness (-1, settings->brightnessValue);
+		hwinfo->setBrightnessPercentage(settings->brightnessValue);
 	}
 
 	// --> set CPU Freq settings
@@ -2205,7 +2210,7 @@ void tdepowersave::handleActionCall ( action action, int value , bool checkAC, b
 				TQTimer::singleShot(100, this, TQT_SLOT(do_freeze()));
 				break;
 			case BRIGHTNESS:
-				hwinfo->setBrightness( -1, value );
+				hwinfo->setBrightnessPercentage(value);
 				break;
 			case CPUFREQ_POWERSAVE:
 				hwinfo->setCPUFreq( POWERSAVE );
@@ -2938,7 +2943,7 @@ int tdepowersave::brightnessGet() {
 	int retval = -1;
 
 	if (hwinfo->supportBrightness()) {
-		retval = (int)(((float)hwinfo->getCurrentBrightnessLevel() / (float)hwinfo->getMaxBrightnessLevel()-1) * 100.0);
+		retval = (int)round(100.0 * hwinfo->getCurrentBrightnessLevel() / hwinfo->getMaxBrightnessLevel());
 	}
 
 	kdDebugFuncOut(trace);
@@ -2946,4 +2951,13 @@ int tdepowersave::brightnessGet() {
 	return retval;
 }
 
+//! dcop funtion to set the brightness level
+void tdepowersave::brightnessSet(int percentage)
+{
+	kdDebugFuncIn(trace);
+
+	hwinfo->setBrightnessPercentage(percentage);
+
+	kdDebugFuncOut(trace);
+}
 #include "tdepowersave.moc"
